FalliblePreference

Struct FalliblePreference 

pub struct FalliblePreference<F, E>
where F: Fn(&[f64]) -> Result<f64, E>,
{ /* private fields */ }
Consumer preference backed by a fallible utility function.

This variant is intended for frontends that need utility evaluation to return errors instead of assuming the utility function is infallible.

Implementations

Source

impl<F, E> FalliblePreference<F, E>
where F: Fn(&[f64]) -> Result<f64, E>,

pub fn with_validation( utility_func: F, min_bounds: Vec<f64>, max_bounds: Vec<f64>, validate: bool, ) -> Result<Self, PreferenceError<E>>

pub fn with_config( utility_func: F, min_bounds: Vec<f64>, max_bounds: Vec<f64>, config: ValidationConfig, calc_config: CalcConfig, ) -> Result<Self, PreferenceError<E>>

pub fn get_utility(&self, bundle: &[f64]) -> Result<f64, PreferenceError<E>>

pub fn min_bounds(&self) -> &[f64]

pub fn max_bounds(&self) -> &[f64]

pub fn get_mu( &self, bundle: &[f64], good: usize, ) -> Result<f64, PreferenceError<E>>

pub fn get_mrs( &self, bundle: &[f64], good_i: usize, good_j: usize, ) -> Result<f64, PreferenceError<E>>